@@ -446,7 +446,7 @@ const SEEDS: [[u8; 256]; 5] = [
 mod tests {
     use super::*;
     use crate::code;
-    use crate::std_alloc::Vec;
+    use crate::std_alloc::{vec, Vec};
     #[cfg(feature = "std")]
     use pretty_assertions::assert_eq;
 
